# G Square Conditional Independence Test

## Overview

This package contains conditional independence test functions using
the G-square test.

The code fragments included in this package are logically copied and
pasted from the pcalg package for R developed by Markus Kalisch, Alain
Hauser, Martin Maechler, Diego Colombo, Doris Entner, Patrik Hoyer,
Antti Hyttinen, and Jonas Peters.
